Class: Packwerk::SpringCommand

Inherits:
Object
  • Object
show all
Defined in:
lib/packwerk/spring_command.rb

Instance Method Summary collapse

Instance Method Details

#callObject

: -> bool



26
27
28
# File 'lib/packwerk/spring_command.rb', line 26

def call
  load(Gem.bin_path(gem_name, exec_name))
end

#env(args) ⇒ Object

: (untyped args) -> String



9
10
11
12
13
# File 'lib/packwerk/spring_command.rb', line 9

def env(args)
  # Packwerk needs to run in a test environment, which has a set of autoload paths that are
  # often a superset of the dev/prod paths (for example, test/support/helpers)
  "test"
end

#exec_nameObject

: -> String



16
17
18
# File 'lib/packwerk/spring_command.rb', line 16

def exec_name
  "packwerk"
end

#gem_nameObject

: -> String



21
22
23
# File 'lib/packwerk/spring_command.rb', line 21

def gem_name
  "packwerk"
end